==> igniteui-react-charts-16.6.8.tgz: package/ES2015/igr-anchored-category-series.js <==
import { TrendLineType_$type } from "igniteui-react-core/ES2015/TrendLineType";
import { CategorySeriesMarkerCollisionAvoidance_$type } from "./CategorySeriesMarkerCollisionAvoidance";
import { ConsolidatedItemHitTestBehavior_$type } from "./ConsolidatedItemHitTestBehavior";
import { IgrCategorySeries } from "./igr-category-series";
import { ensureEnum, brushToString, stringToBrush, toPoint } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent anchored category/value series.
*
* The `IgrAnchoredCategorySeries` represents the base class for all IgxDataChartComponent anchored category/value series.
*
* ```ts
* <IgrDataChart >
*
*
*     <IgrCategoryXAxis name="xAxisYears"
*     interval={12} labelLocation="OutsideBottom"
*     label="Year"  overlap={1} gap={0.4}  />
*
*     <IgrCategoryXAxis name="xAxisMonths"
*     interval={1}  labelLocation="OutsideBottom"
*     label="Month" overlap={1} gap={0.4}/>
*
*     <IgrNumericYAxis  name="yAxisLeft"
*     title="Expanse | Revenue"
*     minimumValue={-900} labelLocation="OutsideLeft"
*     maximumValue={900}
*     interval={300} />
*
*     <IgrNumericYAxis  name="yAxisRight"
*     title="Profit (%)"
*     minimumValue={0}  labelLocation="OutsideRight"
*     maximumValue={100} />
*
*
*     <IgrLineSeries name="series1"
*     valueMemberPath="Revenue"
*     xAxisName="xAxisMonths"
*     yAxisName="yAxisLeft" />
*  </IgrDataChart>
* ```
*/
export class IgrAnchoredCategorySeries extends IgrCategorySeries {
    constructor(props) {
        super(props);
    }
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the value mapping property for the current series object.
    *
    * The `valueMemberPath` property is used for the value mapping property of the current series object.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft" />
    *  </IgrDataChart>
    * ```
    */
    get valueMemberPath() {
        return this.i.o6;
    }
    set valueMemberPath(v) {
        this.i.o6 = v;
    }
    /**
     * Gets or sets the trend type for the current series object.
    *
    * The `trendLineType` property is used for the current series object's trend type.'
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	trendLineType="SimpleAverage" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.trendLineType= "CubicFit";
    * ```
    */
    get trendLineType() {
        return this.i.trendLineType;
    }
    set trendLineType(v) {
        this.i.trendLineType = ensureEnum(TrendLineType_$type, v);
    }
    /**
     * Gets or sets the brush to use to draw the trend line.
    *
    * The `trendLineBrush` property is used to brush the trend line.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	trendLineBrush="Gray"  />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.trendLineBrush="red";
    * ```
    */
    get trendLineBrush() {
        return brushToString(this.i.trendLineBrush);
    }
    set trendLineBrush(v) {
        this.i.trendLineBrush = stringToBrush(v);
    }
    /**
     * Gets the effective TrendLineBrush for this series.
    *
    * The `actualTrendLineBrush` property is used to gets the effective `trendLineBrush` for this series.
    */
    get actualTrendLineBrush() {
        return brushToString(this.i.po);
    }
    set actualTrendLineBrush(v) {
        this.i.po = stringToBrush(v);
    }
    /**
     * Gets or sets the thickness of the current series object's trend line.
    *
    * The `trendLineThickness` property is used for thickness of the current series object's trend line.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	trendLineThickness ="2" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.trendLineThickness= 2;
    * ```
    */
    get trendLineThickness() {
        return this.i.trendLineThickness;
    }
    set trendLineThickness(v) {
        this.i.trendLineThickness = +v;
    }
    /**
     * Gets or sets the trend line period for the current series.
     * The typical, and initial, value for trend line period is 7.
    *
    * The `trendLinePeriod` property is used for trend line period of the current series.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	trendLinePeriod ="2" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.trendLinePeriod= 7;
    * ```
    */
    get trendLinePeriod() {
        return this.i.trendLinePeriod;
    }
    set trendLinePeriod(v) {
        this.i.trendLinePeriod = +v;
    }
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    *
    * The `markerCollisionAvoidance` property controls the technique the chart uses to avoid overlapping markers.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	markerCollisionAvoidance="fade"  />
    *  </IgrDataChart>
    * ```
    */
    get markerCollisionAvoidance() {
        return this.i.ot;
    }
    set markerCollisionAvoidance(v) {
        this.i.ot = ensureEnum(CategorySeriesMarkerCollisionAvoidance_$type, v);
    }
    /**
     * Determines the item returned in hit-testing when the pointer is over an object which represents several consolidated items.
    *
    * The `consolidatedItemHitTestBehavior` property is used to determines returned item in hit-testing when the pointer is over an object which represents several consolidated items.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	consolidatedItemHitTestBehavior="Basic"  />
    *  </IgrDataChart>
    * ```
    */
    get consolidatedItemHitTestBehavior() {
        return this.i.ou;
    }
    set consolidatedItemHitTestBehavior(v) {
        this.i.ou = ensureEnum(ConsolidatedItemHitTestBehavior_$type, v);
    }
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    *
    * The `scrollIntoView` method is used to notifies the target axis or series that it should scroll the requested data item into view.
    *
    * ```ts
    * this.series.scrollIntoView(dataItem);
    * ```
    */
    scrollIntoView(item) {
        let iv = this.i.c8(item);
        return (iv);
    }
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    *
    * The `getItem` method is used to gets the item that is the best match for the specified world coordinates.
    *
    * ```ts
    * let item: number = this.series.getItem({x:.5,y:.5});
    * ```
    */
    getItem(world) {
        let iv = this.i.fm(toPoint(world));
        return (iv);
    }
}

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/igr-anchored-category-series.js <==
import { TrendLineType_$type } from "igniteui-react-core/ES2015/TrendLineType";
import { CategorySeriesMarkerCollisionAvoidance_$type } from "./CategorySeriesMarkerCollisionAvoidance";
import { ConsolidatedItemHitTestBehavior_$type } from "./ConsolidatedItemHitTestBehavior";
import { IgrCategorySeries } from "./igr-category-series";
import { ensureEnum, brushToString, stringToBrush, toPoint } from "igniteui-react-core/ES2015/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent anchored category/value series.
*
* The `IgrAnchoredCategorySeries` represents the base class for all IgxDataChartComponent anchored category/value series.
*
* ```ts
* <IgrDataChart >
*
*
*     <IgrCategoryXAxis name="xAxisYears"
*     interval={12} labelLocation="OutsideBottom"
*     label="Year"  overlap={1} gap={0.4}  />
*
*     <IgrCategoryXAxis name="xAxisMonths"
*     interval={1}  labelLocation="OutsideBottom"
*     label="Month" overlap={1} gap={0.4}/>
*
*     <IgrNumericYAxis  name="yAxisLeft"
*     title="Expanse | Revenue"
*     minimumValue={-900} labelLocation="OutsideLeft"
*     maximumValue={900}
*     interval={300} />
*
*     <IgrNumericYAxis  name="yAxisRight"
*     title="Profit (%)"
*     minimumValue={0}  labelLocation="OutsideRight"
*     maximumValue={100} />
*
*
*     <IgrLineSeries name="series1"
*     valueMemberPath="Revenue"
*     xAxisName="xAxisMonths"
*     yAxisName="yAxisLeft" />
*  </IgrDataChart>
* ```
*/
export class IgrAnchoredCategorySeries extends IgrCategorySeries {
    constructor(props) {
        super(props);
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the value mapping property for the current series object.
    *
    * The `valueMemberPath` property is used for the value mapping property of the current series object.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft" />
    *  </IgrDataChart>
    * ```
    */
    get valueMemberPath() {
        return this.i.pd;
    }
    set valueMemberPath(v) {
        this.i.pd = v;
    }
    /**
     * Gets or sets the trend type for the current series object.
    *
    * The `trendLineType` property is used for the current series object's trend type.'
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	trendLineType="SimpleAverage" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.trendLineType= "CubicFit";
    * ```
    */
    get trendLineType() {
        return this.i.trendLineType;
    }
    set trendLineType(v) {
        this.i.trendLineType = ensureEnum(TrendLineType_$type, v);
    }
    /**
     * Gets or sets the brush to use to draw the trend line.
    *
    * The `trendLineBrush` property is used to brush the trend line.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	trendLineBrush="Gray"  />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.trendLineBrush="red";
    * ```
    */
    get trendLineBrush() {
        return brushToString(this.i.trendLineBrush);
    }
    set trendLineBrush(v) {
        this.i.trendLineBrush = stringToBrush(v);
    }
    /**
     * Gets the effective TrendLineBrush for this series.
    *
    * The `actualTrendLineBrush` property is used to gets the effective `trendLineBrush` for this series.
    */
    get actualTrendLineBrush() {
        return brushToString(this.i.pv);
    }
    set actualTrendLineBrush(v) {
        this.i.pv = stringToBrush(v);
    }
    /**
     * Gets or sets the thickness of the current series object's trend line.
    *
    * The `trendLineThickness` property is used for thickness of the current series object's trend line.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	trendLineThickness ="2" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.trendLineThickness= 2;
    * ```
    */
    get trendLineThickness() {
        return this.i.trendLineThickness;
    }
    set trendLineThickness(v) {
        this.i.trendLineThickness = +v;
    }
    /**
     * Gets or sets the trend line period for the current series.
     * The typical, and initial, value for trend line period is 7.
    *
    * The `trendLinePeriod` property is used for trend line period of the current series.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	trendLinePeriod ="2" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * series.trendLinePeriod= 7;
    * ```
    */
    get trendLinePeriod() {
        return this.i.trendLinePeriod;
    }
    set trendLinePeriod(v) {
        this.i.trendLinePeriod = +v;
    }
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    *
    * The `markerCollisionAvoidance` property controls the technique the chart uses to avoid overlapping markers.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	markerCollisionAvoidance="fade"  />
    *  </IgrDataChart>
    * ```
    */
    get markerCollisionAvoidance() {
        return this.i.o0;
    }
    set markerCollisionAvoidance(v) {
        this.i.o0 = ensureEnum(CategorySeriesMarkerCollisionAvoidance_$type, v);
    }
    /**
     * Determines the item returned in hit-testing when the pointer is over an object which represents several consolidated items.
    *
    * The `consolidatedItemHitTestBehavior` property is used to determines returned item in hit-testing when the pointer is over an object which represents several consolidated items.
    *
    * ```ts
    * <IgrDataChart >
    *
    *
    *     <IgrCategoryXAxis name="xAxisYears"
    *     interval={12} labelLocation="OutsideBottom"
    *     label="Year"  overlap={1} gap={0.4}  />
    *
    *     <IgrCategoryXAxis name="xAxisMonths"
    *     interval={1}  labelLocation="OutsideBottom"
    *     label="Month" overlap={1} gap={0.4}/>
    *
    *     <IgrNumericYAxis  name="yAxisLeft"
    *     title="Expanse | Revenue"
    *     minimumValue={-900} labelLocation="OutsideLeft"
    *     maximumValue={900}
    *     interval={300} />
    *
    *     <IgrNumericYAxis  name="yAxisRight"
    *     title="Profit (%)"
    *     minimumValue={0}  labelLocation="OutsideRight"
    *     maximumValue={100} />
    *
    *
    *     <IgrLineSeries name="series1"
    *     valueMemberPath="Revenue"
    *     xAxisName="xAxisMonths"
    *     yAxisName="yAxisLeft"
    * 	consolidatedItemHitTestBehavior="Basic"  />
    *  </IgrDataChart>
    * ```
    */
    get consolidatedItemHitTestBehavior() {
        return this.i.o1;
    }
    set consolidatedItemHitTestBehavior(v) {
        this.i.o1 = ensureEnum(ConsolidatedItemHitTestBehavior_$type, v);
    }
    getItemValue(item, memberPathName) {
        let iv = this.i.fs(item, memberPathName);
        return (iv);
    }
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    *
    * The `scrollIntoView` method is used to notifies the target axis or series that it should scroll the requested data item into view.
    *
    * ```ts
    * this.series.scrollIntoView(dataItem);
    * ```
    */
    scrollIntoView(item) {
        let iv = this.i.c9(item);
        return (iv);
    }
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    *
    * The `getItem` method is used to gets the item that is the best match for the specified world coordinates.
    *
    * ```ts
    * let item: number = this.series.getItem({x:.5,y:.5});
    * ```
    */
    getItem(world) {
        let iv = this.i.fp(toPoint(world));
        return (iv);
    }
}
